@@ -168,8 +168,7 @@ class InvoiceTemplate(OrderedDict):
                             if sum_field:
                                 res_find += res_val
                             else:
-                                res_find = res_val
-                                break
+                                res_find.extend(res_val)
                 else:
                     res_find = re.findall(v, optimized_str)
                 if res_find:
@@ -188,7 +187,11 @@ class InvoiceTemplate(OrderedDict):
                         else:
                             output[k] = self.parse_number(res_find[0])
                     else:
-                        output[k] = res_find[0]
+                        res_find = list(set(res_find))
+                        if len(res_find) == 1:
+                            output[k] = res_find[0]
+                        else:
+                            output[k] = res_find
                 else:
                     logger.warning("regexp for field %s didn't match", k)
 
@@ -200,16 +203,15 @@ class InvoiceTemplate(OrderedDict):
                 plugin_func.extract(self, optimized_str, output)
 
         # If required fields were found, return output, else log error.
-        if 'required-fields' not in self.keys():
+        if 'required_fields' not in self.keys():
             required_fields = ['date', 'amount', 'invoice_number', 'issuer']
         else:
             required_fields = []
-            for v in self['required-fields']:
+            for v in self['required_fields']:
                 required_fields.append(v)
-        
+
         if set(required_fields).issubset(output.keys()):
-                output['desc'] = 'Invoice %s from %s' % (
-                    output['invoice_number'], self['issuer'])
+                output['desc'] = 'Invoice from %s' % (self['issuer'])
                 logger.debug(output)
                 return output
         else:
