@@ -1,6 +1,6 @@
 import json
 import datetime
-
+import codecs
 
 def myconverter(o):
     """function to serialise datetime"""
@@ -36,7 +36,7 @@ def write_to_file(data, path):
     else:
         filename = path + '.json'
 
-    with open(filename, "w") as json_file:
+    with codecs.open(filename, "w", encoding='utf-8') as json_file:
         for line in data:
             line['date'] = line['date'].strftime('%d/%m/%Y')
-        json.dump(data, json_file, indent=4,  sort_keys=True, default = myconverter)
+        json.dump(data, json_file, indent=4,  sort_keys=True, default = myconverter, ensure_ascii=False)
